@@ -1,5 +1,5 @@
-from typing import Any,  Optional, Dict
-from src.pygating.pygating import AbstractGate
+from typing import Any,  Optional
+from ..pygating import AbstractGate
 
 class SimpleGate(AbstractGate):
     def _check_gate(self, entity: Optional[Any] = None) -> bool:
